==> openGion_dev_5.9.17.1.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF60S.sql <==
/****************************************************************************/
/* GF60 ( ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF60 (
   ID       varchar           (  30 )                   NOT NULL            /*  10 ID           */
 , IDTYPE   varchar           (  20 )                   NOT NULL            /*  20 IDﾀｲﾌﾟ       */
 , SEQ      INTEGER                         DEFAULT 0   NOT NULL            /*  30 順           */
 , FORM     varchar           (  20 )                   NOT NULL            /*  40 FORM         */
 , NAME_JA  varchar           ( 200 )                                       /*  50 名称         */
 , DEF1     varchar           ( 100 )                                       /*  60 項目定義1    */
 , DEF2     varchar           ( 100 )                                       /*  70 項目定義2    */
 , DEF3     varchar           ( 100 )                                       /*  80 項目定義3    */
 , DEF4     varchar           ( 100 )                                       /*  90 項目定義4    */
 , DEF5     varchar           ( 100 )                                       /* 100 項目定義5    */
 , DEF6     varchar           ( 100 )                                       /* 110 項目定義6    */
 , ROLES    varchar           ( 500 )                                       /* 120 ﾛｰﾙｽﾞ        */
 , DYKAN    varchar           (   8 )                                       /* 130 完成日       */
 , URL      varchar           ( 200 )                                       /* 140 URL          */
 , CDKATU   varchar           (   1 )                                       /* 150 活動CD       */
 , UNIQ     int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET    varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET   varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET   varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD    varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD    varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD   varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD   varchar           (  10 )                                       /* 890 更新者       */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF60S.sql <==
/****************************************************************************/
/* GF60 ( ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF60 (
   ID       varchar           (  30 )                   NOT NULL            /*  10 ID           */
 , IDTYPE   varchar           (  20 )                   NOT NULL            /*  20 IDﾀｲﾌﾟ       */
 , SEQ      INTEGER                         DEFAULT 0   NOT NULL            /*  30 順           */
 , FORM     varchar           (  20 )                   NOT NULL            /*  40 FORM         */
 , NAME_JA  varchar           ( 200 )                                       /*  50 名称         */
 , DEF1     varchar           ( 100 )                                       /*  60 項目定義1    */
 , DEF2     varchar           ( 100 )                                       /*  70 項目定義2    */
 , DEF3     varchar           ( 100 )                                       /*  80 項目定義3    */
 , DEF4     varchar           ( 100 )                                       /*  90 項目定義4    */
 , DEF5     varchar           ( 100 )                                       /* 100 項目定義5    */
 , DEF6     varchar           ( 100 )                                       /* 110 項目定義6    */
 , ROLES    varchar           ( 500 )                                       /* 120 ﾛｰﾙｽﾞ        */
 , DYKAN    varchar           (   8 )                                       /* 130 完成日       */
 , URL      varchar           ( 200 )                                       /* 140 URL          */
 , CDKATU   varchar           (   1 )                                       /* 150 活動CD       */
 , UNIQ     int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET    varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET   varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET   varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD    varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD    varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD   varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD   varchar           (  10 )                                       /* 890 更新者       */
);
